@@ -1,24 +1,24 @@
 mod anomalies;
 mod instruction;
-pub mod scanner;
+pub(crate) mod scanner;
 mod span;
 mod token;
-pub mod tokenizer;
-pub mod walker;
+pub(crate) mod tokenizer;
+pub(crate) mod walker;
 
 pub use anomalies::{Error, Warning};
-pub use instruction::{Instruction, InstructionKind};
-pub use span::{Location, Span, Spanned, Spanning};
-pub use token::{Identifier, Token};
+pub(crate) use instruction::{Instruction, InstructionKind};
+pub(crate) use span::{Location, Span, Spanned, Spanning};
+pub(crate) use token::{Identifier, Token};
 use walker::walk;
 
-pub fn assemble(
-    input_file_contents: impl AsRef<str>,
-) -> Result<(Vec<u8>, Vec<Warning>), (Vec<Error>, Vec<Warning>)> {
+pub type Result<T> = std::result::Result<(T, Vec<Warning>), (Vec<Error>, Vec<Warning>)>;
+
+pub fn assemble(source: impl AsRef<str>) -> Result<Vec<u8>> {
     let mut errors = Vec::new();
     let mut warnings = Vec::new();
 
-    let words = match scanner::scan(input_file_contents.as_ref()) {
+    let words = match scanner::scan(source.as_ref()) {
         Ok((words, new_warnings)) => {
             warnings.extend(new_warnings.iter().cloned().map(Warning::from));
             words
