@@ -1,21 +1,20 @@
-use std::fmt;
 use super::{Identifier, Token};
 use super::{Span, Spanned, Spanning};
+use crate::anomalies::{Error, Warning};
 use crate::{Instruction, InstructionKind};
-pub use anomalies::{Error, Warning};
+use std::fmt;
 
-mod anomalies;
 mod hex_number;
 
 #[derive(Clone)]
 enum Evaluated {
     Fine {
         token: Spanned<Token>,
-        warnings: Vec<crate::Warning>,
+        warnings: Vec<Warning>,
     },
     Faulty {
-        errors: Vec<crate::Error>,
-        warnings: Vec<crate::Warning>,
+        errors: Vec<Error>,
+        warnings: Vec<Warning>,
     },
 }
 
@@ -29,12 +28,12 @@ impl fmt::Debug for Evaluated {
 }
 
 #[derive(Debug, Clone)]
-pub struct Word {
+pub(crate) struct Word {
     evaluated: Evaluated,
 }
 
 impl Word {
-    pub fn new(symbols: &[Spanned<char>]) -> Self {
+    pub(crate) fn new(symbols: &[Spanned<char>]) -> Self {
         debug_assert!({
             const WHITESPACES: [char; 6] = [' ', '\t', '\n', 0x0b as char, 0x0c as char, '\r'];
 
@@ -53,10 +52,9 @@ impl Word {
         Self { evaluated }
     }
 
-    pub fn get_token(
+    pub(crate) fn get_token(
         &self,
-    ) -> Result<(Spanned<Token>, Vec<crate::Warning>), (Vec<crate::Error>, Vec<crate::Warning>)>
-    {
+    ) -> Result<(Spanned<Token>, Vec<Warning>), (Vec<Error>, Vec<Warning>)> {
         match &self.evaluated {
             Evaluated::Fine { token, warnings } => Ok((token.clone(), warnings.clone())),
             Evaluated::Faulty { errors, warnings } => Err((errors.clone(), warnings.clone())),
@@ -64,7 +62,7 @@ impl Word {
     }
 }
 
-fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<crate::Warning>), crate::Error> {
+fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<Warning>), Error> {
     match word.first().cloned().unwrap() {
         Spanned { node: '[', span } => {
             return Ok((Token::OpeningBracket.spanning(span), Vec::new()))
@@ -81,33 +79,27 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<crate::Warnin
                     Vec::new(),
                 ));
             }
-            Err(err) => Err(err.into()),
+            Err(err) => Err(err),
         },
         Spanned { node: '|', span } => hex_number::parse_hex_number_unconstrained(&word[1..])
-            .map_err(|err| {
-                match err {
-                    hex_number::Error2::DigitExpected => Error::HexNumberExpected { span },
-                    hex_number::Error2::DigitInvalid { digit, span } => Error::HexDigitInvalid {
-                        digit,
-                        number: to_string(&word[1..]),
-                        span,
-                    },
-                }
-                .into()
+            .map_err(|err| match err {
+                hex_number::Error2::DigitExpected => Error::HexNumberExpected { span: span.into() },
+                hex_number::Error2::DigitInvalid { digit, span } => Error::HexDigitInvalid {
+                    digit,
+                    number: to_string(&word[1..]),
+                    span: span.into(),
+                },
             })
             .map(|value| Token::PadAbsolute(value))
             .map(|token| (token.spanning(to_span(word).unwrap()), Vec::new())),
         Spanned { node: '$', span } => hex_number::parse_hex_number_unconstrained(&word[1..])
-            .map_err(|err| {
-                match err {
-                    hex_number::Error2::DigitExpected => Error::HexNumberExpected { span },
-                    hex_number::Error2::DigitInvalid { digit, span } => Error::HexDigitInvalid {
-                        digit,
-                        number: to_string(&word[1..]),
-                        span,
-                    },
-                }
-                .into()
+            .map_err(|err| match err {
+                hex_number::Error2::DigitExpected => Error::HexNumberExpected { span: span.into() },
+                hex_number::Error2::DigitInvalid { digit, span } => Error::HexDigitInvalid {
+                    digit,
+                    number: to_string(&word[1..]),
+                    span: span.into(),
+                },
             })
             .map(|value| Token::PadRelative(value))
             .map(|token| (token.spanning(to_span(word).unwrap()), Vec::new())),
@@ -120,9 +112,8 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<crate::Warnin
                         .position(|c| c == '/')
                     {
                         Err(Error::SlashInLabelOrSublabel {
-                            span: word[1 + position].span,
-                        }
-                        .into())
+                            span: word[1 + position].span.into(),
+                        })
                     } else {
                         Ok((
                             Token::LabelDefine(to_string(&word[1..]))
@@ -131,10 +122,12 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<crate::Warnin
                         ))
                     }
                 } else {
-                    Err(Error::AmpersandAtTheStartOfLabel { span: word[1].span }.into())
+                    Err(Error::AmpersandAtTheStartOfLabel {
+                        span: word[1].span.into(),
+                    })
                 }
             } else {
-                Err(Error::LabelExpected { span }.into())
+                Err(Error::LabelExpected { span: span.into() })
             }
         }
         Spanned { node: '&', span } => {
@@ -145,9 +138,8 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<crate::Warnin
                     .position(|c| c == '/')
                 {
                     Err(Error::SlashInLabelOrSublabel {
-                        span: word[1 + position].span,
-                    }
-                    .into())
+                        span: word[1 + position].span.into(),
+                    })
                 } else {
                     Ok((
                         Token::SublabelDefine(to_string(&word[1..]))
@@ -156,36 +148,33 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<crate::Warnin
                     ))
                 }
             } else {
-                Err(Error::LabelExpected { span }.into())
+                Err(Error::LabelExpected { span: span.into() })
             }
         }
         Spanned { node: '#', span } => match hex_number::parse_hex_number(&word[1..]) {
             Ok(hex_number::HexNumber::Byte(value)) => Ok(Token::LiteralHexByte(value)),
             Ok(hex_number::HexNumber::Short(value)) => Ok(Token::LiteralHexShort(value)),
             Err(hex_number::Error::DigitExpected) => {
-                Err(Error::HexNumberOrCharacterExpected { span }.into())
+                Err(Error::HexNumberOrCharacterExpected { span: span.into() })
             }
             Err(hex_number::Error::DigitInvalid { digit, span }) => Err(Error::HexDigitInvalid {
                 digit,
                 number: to_string(&word[1..]),
-                span,
-            }
-            .into()),
+                span: span.into(),
+            }),
             Err(hex_number::Error::UnevenLength { length: 1 }) => {
                 Ok(Token::LiteralHexByte(word[1].node as u8))
             }
             Err(hex_number::Error::UnevenLength { length }) => Err(Error::HexNumberUnevenLength {
                 length,
                 number: to_string(&word[1..]),
-                span: to_span(&word[1..]).unwrap(),
-            }
-            .into()),
+                span: to_span(&word[1..]).unwrap().into(),
+            }),
             Err(hex_number::Error::TooLong { length }) => Err(Error::HexNumberTooLong {
                 length,
                 number: to_string(&word[1..]),
-                span: to_span(&word[1..]).unwrap(),
-            }
-            .into()),
+                span: to_span(&word[1..]).unwrap().into(),
+            }),
         }
         .map(|token| (token.spanning(to_span(word).unwrap()), Vec::new())),
         Spanned { node: '.', span } => match parse_identifier(span, &word[1..]) {
@@ -195,7 +184,7 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<crate::Warnin
                     Vec::new(),
                 ));
             }
-            Err(err) => Err(err.into()),
+            Err(err) => Err(err),
         },
         Spanned { node: ',', span } => match parse_identifier(span, &word[1..]) {
             Ok(name) => {
@@ -204,7 +193,7 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<crate::Warnin
                     Vec::new(),
                 ));
             }
-            Err(err) => Err(err.into()),
+            Err(err) => Err(err),
         },
         Spanned { node: ';', span } => match parse_identifier(span, &word[1..]) {
             Ok(name) => {
@@ -213,7 +202,7 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<crate::Warnin
                     Vec::new(),
                 ));
             }
-            Err(err) => Err(err.into()),
+            Err(err) => Err(err),
         },
         Spanned { node: ':', span } => match parse_identifier(span, &word[1..]) {
             Ok(name) => {
@@ -222,19 +211,22 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<crate::Warnin
                     Vec::new(),
                 ));
             }
-            Err(err) => Err(err.into()),
+            Err(err) => Err(err),
         },
         Spanned { node: '\'', span } => {
             let bytes: Vec<u8> = to_string(&word[1..]).bytes().collect();
             match bytes.len() {
-                0 => Err(Error::CharacterExpected { span }.into()),
+                0 => Err(Error::CharacterExpected { span: span.into() }),
                 1 => Ok((
                     Token::RawChar(bytes[0]).spanning(Span::combine(&span, &word[1].span)),
                     Vec::new(),
                 )),
                 _ => {
                     let span = to_span(&word[1..]).unwrap();
-                    Err(Error::MoreThanOneByteFound { bytes, span }.into())
+                    Err(Error::MoreThanOneByteFound {
+                        bytes,
+                        span: span.into(),
+                    })
                 }
             }
         }
@@ -285,18 +277,20 @@ fn to_spanned_string(symbols: &[Spanned<char>]) -> Option<Spanned<String>> {
 
 fn parse_macro(rune_span: Span, symbols: &[Spanned<char>]) -> Result<String, Error> {
     if symbols.is_empty() {
-        return Err(Error::MacroNameExpected { span: rune_span });
+        return Err(Error::MacroNameExpected {
+            span: rune_span.into(),
+        });
     }
 
     if let Ok(_) = hex_number::parse_hex_number(symbols) {
         return Err(Error::MacroCannotBeAHexNumber {
-            span: to_span(symbols).unwrap(),
+            span: to_span(symbols).unwrap().into(),
             number: to_string(symbols),
         });
     }
     if let Some(_) = parse_instruction(symbols) {
         return Err(Error::MacroCannotBeAnInstruction {
-            span: to_span(symbols).unwrap(),
+            span: to_span(symbols).unwrap().into(),
             instruction: to_string(symbols),
         });
     }
@@ -306,13 +300,17 @@ fn parse_macro(rune_span: Span, symbols: &[Spanned<char>]) -> Result<String, Err
 
 fn parse_identifier(rune_span: Span, symbols: &[Spanned<char>]) -> Result<Identifier, Error> {
     if symbols.is_empty() {
-        return Err(Error::IdentifierExpected { span: rune_span });
+        return Err(Error::IdentifierExpected {
+            span: rune_span.into(),
+        });
     }
 
     if let Some(Spanned { node: '&', span }) = symbols.first() {
         let rune_span = Span::combine(&rune_span, &span);
         if symbols[1..].is_empty() {
-            return Err(Error::SublabelExpected { span: rune_span });
+            return Err(Error::SublabelExpected {
+                span: rune_span.into(),
+            });
         }
         return Ok(Identifier::Sublabel(to_string(&symbols[1..])));
     }
@@ -329,14 +327,16 @@ fn parse_identifier(rune_span: Span, symbols: &[Spanned<char>]) -> Result<Identi
                 .position(|c| c == '/')
             {
                 return Err(Error::MoreThanOneSlashInIdentifier {
-                    span: symbols[position + 1 + second_position].span,
+                    span: symbols[position + 1 + second_position].span.into(),
                 });
             }
 
             let label = {
                 let label_symbols = &symbols[..position];
                 if label_symbols.is_empty() {
-                    return Err(Error::LabelExpected { span: rune_span });
+                    return Err(Error::LabelExpected {
+                        span: rune_span.into(),
+                    });
                 }
                 to_string(label_symbols)
             };
@@ -344,7 +344,7 @@ fn parse_identifier(rune_span: Span, symbols: &[Spanned<char>]) -> Result<Identi
                 let sublabel_symbols = &symbols[position + 1..];
                 if sublabel_symbols.is_empty() {
                     return Err(Error::SublabelExpected {
-                        span: symbols[position].span,
+                        span: symbols[position].span.into(),
                     });
                 }
                 to_string(sublabel_symbols)
@@ -353,7 +353,9 @@ fn parse_identifier(rune_span: Span, symbols: &[Spanned<char>]) -> Result<Identi
         }
         None => {
             if symbols.is_empty() {
-                return Err(Error::LabelExpected { span: rune_span });
+                return Err(Error::LabelExpected {
+                    span: rune_span.into(),
+                });
             }
             Ok(Identifier::Label(to_string(symbols)))
         }
@@ -361,7 +363,7 @@ fn parse_identifier(rune_span: Span, symbols: &[Spanned<char>]) -> Result<Identi
 }
 
 /// `symbols` must not be empty.
-fn parse_instruction(symbols: &[Spanned<char>]) -> Option<(Instruction, Vec<crate::Warning>)> {
+fn parse_instruction(symbols: &[Spanned<char>]) -> Option<(Instruction, Vec<Warning>)> {
     if symbols.len() < 3 {
         return None;
     }
@@ -411,43 +413,34 @@ fn parse_instruction(symbols: &[Spanned<char>]) -> Option<(Instruction, Vec<crat
         match ch {
             'k' => {
                 if let Some(other_span) = keep {
-                    warnings.push(
-                        Warning::InstructionModeDefinedMoreThanOnce {
-                            instruction_mode: 'k',
-                            instruction: to_string(&symbols[..3]),
-                            span: *span,
-                            other_span,
-                        }
-                        .into(),
-                    );
+                    warnings.push(Warning::InstructionModeDefinedMoreThanOnce {
+                        instruction_mode: 'k',
+                        instruction: to_string(&symbols[..3]),
+                        span: (*span).into(),
+                        other_span: other_span.into(),
+                    });
                 }
                 keep = Some(*span);
             }
             'r' => {
                 if let Some(other_span) = r#return {
-                    warnings.push(
-                        Warning::InstructionModeDefinedMoreThanOnce {
-                            instruction_mode: 'r',
-                            instruction: to_string(&symbols[..3]),
-                            span: *span,
-                            other_span,
-                        }
-                        .into(),
-                    );
+                    warnings.push(Warning::InstructionModeDefinedMoreThanOnce {
+                        instruction_mode: 'r',
+                        instruction: to_string(&symbols[..3]),
+                        span: (*span).into(),
+                        other_span: other_span.into(),
+                    });
                 }
                 r#return = Some(*span);
             }
             '2' => {
                 if let Some(other_span) = short {
-                    warnings.push(
-                        Warning::InstructionModeDefinedMoreThanOnce {
-                            instruction_mode: '2',
-                            instruction: to_string(&symbols[..3]),
-                            span: *span,
-                            other_span,
-                        }
-                        .into(),
-                    );
+                    warnings.push(Warning::InstructionModeDefinedMoreThanOnce {
+                        instruction_mode: '2',
+                        instruction: to_string(&symbols[..3]),
+                        span: (*span).into(),
+                        other_span: other_span.into(),
+                    });
                 }
                 short = Some(*span);
             }
